@@ -13,12 +13,8 @@ from checksec.pe import PEChecksecData
 
 
 class AbstractChecksecOutput(ABC):
-    def __init__(self, total: int):
-        """
-
-        :param total: Total number of checksec elements to be processed
-        """
-        self.total = total
+    def __init__(self):
+        self.total = None
 
     def __enter__(self):
         return self
@@ -26,6 +22,21 @@ class AbstractChecksecOutput(ABC):
     def __exit__(self, exc_type, exc_val, exc_tb):
         return
 
+    @abstractmethod
+    def enumerating_tasks_start(self):
+        """The tasks enumeration will be started"""
+        pass
+
+    @abstractmethod
+    def enumerating_tasks_stop(self, total: int):
+        """The tasks enumeration has stopped"""
+        self.total = total
+
+    @abstractmethod
+    def processing_tasks_start(self):
+        """Task processing has started"""
+        pass
+
     @abstractmethod
     def add_checksec_result(self, filepath: Path, checksec: Union[ELFChecksecData, PEChecksecData]):
         """Add a checksec file result to the output"""
@@ -43,9 +54,9 @@ class AbstractChecksecOutput(ABC):
 
 
 class RichOutput(AbstractChecksecOutput):
-    def __init__(self, total: int):
+    def __init__(self):
         """Init Rich Console and Table"""
-        super().__init__(total)
+        super().__init__()
         # init ELF table
         self.table_elf = Table(title="Checksec Results: ELF", expand=True)
         self.table_elf.add_column("File", justify="left", header_style="")
@@ -75,18 +86,47 @@ class RichOutput(AbstractChecksecOutput):
         self.table_pe.add_column("Control Flow Guard", justify="center")
         self.table_pe.add_column("Isolation", justify="center")
 
-        # build progress bar
-        self.progress_bar = Progress(
-            TextColumn("[bold blue]Processing...", justify="left"),
-            BarColumn(bar_width=None),
-            "[progress.percentage]{task.percentage:>3.1f}%",
-        )
         # init console
         self.console = Console()
 
+        # build progress bar
+        self.process_bar = Progress(
+            TextColumn("[bold blue]Processing...", justify="left"),
+            BarColumn(bar_width=None),
+            "{task.completed}/{task.total}",
+            "•",
+            "[progress.percentage]{task.percentage:>3.1f}%",
+            console=self.console,
+        )
+        self.display_res_bar = Progress(
+            BarColumn(bar_width=None),
+            TextColumn("[bold blue]{task.description}", justify="center"),
+            BarColumn(bar_width=None),
+            console=self.console,
+            transient=True,
+        )
+        self.enumerate_bar = Progress(
+            TextColumn("[bold blue]Enumerating...", justify="center"),
+            BarColumn(bar_width=None),
+            console=self.console,
+            transient=True,
+        )
+
+        self.process_task_id = None
+
+    def enumerating_tasks_start(self):
+        # start progress bar
+        self.enumerate_bar.start()
+        self.enumerate_bar.add_task("Enumerating", start=False)
+
+    def enumerating_tasks_stop(self, total: int):
+        super().enumerating_tasks_stop(total)
+        self.enumerate_bar.stop()
+
+    def processing_tasks_start(self):
         # init progress bar
-        self.bar = self.progress_bar.__enter__()
-        self.task_id = self.bar.add_task("Checking", total=self.total)
+        self.process_bar.start()
+        self.process_task_id = self.process_bar.add_task("Checking", total=self.total)
 
     def add_checksec_result(self, filepath: Path, checksec: Union[ELFChecksecData, PEChecksecData]):
         if isinstance(checksec, ELFChecksecData):
@@ -247,19 +287,26 @@ class RichOutput(AbstractChecksecOutput):
 
     def checksec_result_end(self):
         """Update progress bar"""
-        self.bar.update(self.task_id, advance=1)
+        self.process_bar.update(self.process_task_id, advance=1)
 
     def print(self):
-        self.progress_bar.__exit__(None, None, None)
+        self.process_bar.stop()
+
         if self.table_elf.row_count > 0:
-            self.console.print(self.table_elf)
+            with self.display_res_bar:
+                task_id = self.display_res_bar.add_task("Displaying Results: ELF ...", start=False)
+                self.console.print(self.table_elf)
+                self.display_res_bar.remove_task(task_id)
         if self.table_pe.row_count > 0:
-            self.console.print(self.table_pe)
+            with self.display_res_bar:
+                task_id = self.display_res_bar.add_task("Displaying Results: PE ...", start=False)
+                self.console.print(self.table_pe)
+                self.display_res_bar.remove_task(task_id)
 
 
 class JSONOutput(AbstractChecksecOutput):
-    def __init__(self, total: int):
-        super().__init__(total)
+    def __init__(self):
+        super().__init__()
         self.data = {}
 
     def add_checksec_result(self, filepath: Path, checksec: Union[ELFChecksecData, PEChecksecData]):
